@@ -1,7 +1,7 @@
-/* 
+/*
  *   Gnome Nibbles: Gnome Worm Game
  *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
- * 
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -21,10 +21,11 @@
 #define _PREFERENCES_H_
 
 #include <config.h>
-#include <gnome.h>
+
+#include <gtk/gtk.h>
 
 #include "properties.h"
 
-void gnibbles_preferences_cb (GtkWidget *widget, gpointer data);
+void gnibbles_preferences_cb (GtkWidget * widget, gpointer data);
 
 #endif
