@@ -21,29 +21,50 @@
 
 #include <config.h>
 
-#include <math.h>
-
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "games-scores-dialog.h"
-#include "games-scores-dialog-private.h"
 #include "games-gtk-compat.h"
 
 G_DEFINE_TYPE (GamesScoresDialog, games_scores_dialog, GTK_TYPE_DIALOG);
 
+struct GamesScoresDialogPrivate {
+  GtkWidget *message;
+  GtkWidget *hdiv;
+  GtkWidget *combo;
+  GtkWidget *label;
+  GtkWidget *catbar;
+  GtkListStore *list;
+  GtkTreeView *treeview;
+  GtkCellRenderer *namerenderer;
+  GtkTreeViewColumn *column;
+  GtkTreeViewColumn *namecolumn;
+  GamesScores *scores;
+  GHashTable *categories;
+  GHashTable *catindices;
+  gint catcounter;
+  gint hilight;
+  gint sethilight;
+  gboolean preservehilight;
+  gulong cursor_handler_id;
+
+  /* FIXME: This should be a property. */
+  gint style;
+};
+
 static void
 games_scores_dialog_finalize (GObject *o)
 {
   GamesScoresDialog *dialog = GAMES_SCORES_DIALOG (o);
 
-  if (dialog->_priv->scores)
-    g_object_unref (dialog->_priv->scores);
+  if (dialog->priv->scores)
+    g_object_unref (dialog->priv->scores);
 
-  if (dialog->_priv->categories)
-    g_hash_table_destroy (dialog->_priv->categories);
-  if (dialog->_priv->catindices)
-    g_hash_table_destroy (dialog->_priv->catindices);
+  if (dialog->priv->categories)
+    g_hash_table_destroy (dialog->priv->categories);
+  if (dialog->priv->catindices)
+    g_hash_table_destroy (dialog->priv->catindices);
 
   G_OBJECT_CLASS (games_scores_dialog_parent_class)->finalize (o);
 }
@@ -74,13 +95,13 @@ static void games_scores_dialog_add_category (GamesScoresDialog *self,
 
   k = g_strdup (key);
 
-  g_hash_table_insert (self->_priv->categories, k, 
-			 GINT_TO_POINTER (self->_priv->catcounter));
-  g_hash_table_insert (self->_priv->catindices, 
-			 GINT_TO_POINTER (self->_priv->catcounter),
+  g_hash_table_insert (self->priv->categories, k, 
+			 GINT_TO_POINTER (self->priv->catcounter));
+  g_hash_table_insert (self->priv->catindices, 
+			 GINT_TO_POINTER (self->priv->catcounter),
 			 k);
-  self->_priv->catcounter++;
-  gtk_combo_box_append_text (GTK_COMBO_BOX (self->_priv->combo), name);
+  self->priv->catcounter++;
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (self->priv->combo), name);
 }
 
 /* This is a helper function for loading the initial list of categories
@@ -106,9 +127,9 @@ static void games_scores_dialog_load_categories (GamesScoresCategory *cat,
 static void games_scores_dialog_set_style (GamesScoresDialog *self, 
 					   GamesScoreStyle style) 
 {
-  gchar *header;
+  const gchar *header;
 
-  self->_priv->style = style;
+  self->priv->style = style;
   switch (style) {
   case GAMES_SCORES_STYLE_TIME_DESCENDING:
   case GAMES_SCORES_STYLE_TIME_ASCENDING:
@@ -120,7 +141,7 @@ static void games_scores_dialog_set_style (GamesScoresDialog *self,
     header = _("Score");
   }
 
-  gtk_tree_view_column_set_title (self->_priv->column, header);
+  gtk_tree_view_column_set_title (self->priv->column, header);
 }
 
 /**
@@ -137,11 +158,11 @@ static void games_scores_dialog_set_category (GamesScoresDialog *self,
   gpointer value;
   int idx;
 
-  value = g_hash_table_lookup (self->_priv->categories, key);
+  value = g_hash_table_lookup (self->priv->categories, key);
   idx = GPOINTER_TO_INT (value);
 
-  self->_priv->preservehilight = TRUE;
-  gtk_combo_box_set_active (GTK_COMBO_BOX (self->_priv->combo), idx);
+  self->priv->preservehilight = TRUE;
+  gtk_combo_box_set_active (GTK_COMBO_BOX (self->priv->combo), idx);
 }
 
 /**
@@ -159,9 +180,9 @@ GtkWidget * games_scores_dialog_new (GtkWindow *parent_window, GamesScores *scor
 {
   GamesScoresDialog *dialog = GAMES_SCORES_DIALOG (g_object_new (GAMES_TYPE_SCORES_DIALOG, NULL));
 
-  dialog->_priv->scores = g_object_ref (scores);
+  dialog->priv->scores = g_object_ref (scores);
   games_scores_dialog_set_style (dialog, games_scores_get_style (scores));
-  dialog->_priv->preservehilight = FALSE;
+  dialog->priv->preservehilight = FALSE;
 
   gtk_window_set_title (GTK_WINDOW (dialog), title);
   gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent_window));
@@ -170,8 +191,8 @@ GtkWidget * games_scores_dialog_new (GtkWindow *parent_window, GamesScores *scor
                                   (GamesScoresCategoryForeachFunc) games_scores_dialog_load_categories,
                                   dialog);
 
-  if (dialog->_priv->catcounter <= 1) {
-    gtk_widget_hide (dialog->_priv->catbar);
+  if (dialog->priv->catcounter <= 1) {
+    gtk_widget_hide (dialog->priv->catbar);
   }
 
   return (GtkWidget *)dialog;
@@ -185,23 +206,23 @@ static void games_scores_dialog_name_edited (GtkCellRendererText *cell,
   GtkTreeIter iter;
   gchar *old_name = NULL;
 
-  gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (self->_priv->list), 
+  gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (self->priv->list), 
 				       &iter, path);
 
   /* Get old name for comparison */
-  gtk_tree_model_get (GTK_TREE_MODEL (self->_priv->list),
+  gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list),
                       &iter, 0, &old_name, -1);
                            
-  gtk_list_store_set (self->_priv->list, &iter, 0, new_text, -1);
+  gtk_list_store_set (self->priv->list, &iter, 0, new_text, -1);
 
-  games_scores_update_score_name (self->_priv->scores, new_text, old_name);
+  games_scores_update_score_name (self->priv->scores, new_text, old_name);
 }
 
 /* Prevent editing of any cell in the high score list but the one we set. */
 static void games_scores_dialog_cursor_changed (GtkTreeView *treeview, 
 						GamesScoresDialog *self)
 {
-  g_object_set (self->_priv->namerenderer, "editable", FALSE, NULL);
+  g_object_set (self->priv->namerenderer, "editable", FALSE, NULL);
 }    
 
 /* These contortions are to ensure that only the single most-recent
@@ -212,21 +233,21 @@ static gboolean games_scores_dialog_set_edit (GamesScoresDialog *self)
   GtkTreeSelection *selection;
 
   /* Just in case we've been closed as soon as we're created. */
-  if (!GTK_WIDGET_REALIZED (self))
+  if (!gtk_widget_get_realized (GTK_WIDGET (self)))
     return FALSE;
 
   /* Temporarily disable the code that prevents editing when the
    * cursor changes position. */
-  g_signal_handler_block (self->_priv->treeview, 
-			    self->_priv->cursor_handler_id); 
-  g_object_set (self->_priv->namerenderer, "editable", TRUE, NULL);
-  selection = gtk_tree_view_get_selection (self->_priv->treeview);
-  path = gtk_tree_path_new_from_indices (self->_priv->hilight - 1, -1);
+  g_signal_handler_block (self->priv->treeview, 
+			    self->priv->cursor_handler_id); 
+  g_object_set (self->priv->namerenderer, "editable", TRUE, NULL);
+  selection = gtk_tree_view_get_selection (self->priv->treeview);
+  path = gtk_tree_path_new_from_indices (self->priv->hilight - 1, -1);
   gtk_tree_selection_select_path (selection, path);
-  gtk_tree_view_set_cursor (self->_priv->treeview, path, 
-			      self->_priv->namecolumn, TRUE);
-  g_signal_handler_unblock (self->_priv->treeview, 
-			      self->_priv->cursor_handler_id); 
+  gtk_tree_view_set_cursor (self->priv->treeview, path, 
+			      self->priv->namecolumn, TRUE);
+  g_signal_handler_unblock (self->priv->treeview, 
+			      self->priv->cursor_handler_id); 
   gtk_tree_path_free (path);
 
   return FALSE;
@@ -236,15 +257,15 @@ static gboolean games_scores_dialog_set_edit (GamesScoresDialog *self)
  * editable. */
 static void games_scores_dialog_set_hilight_private (GamesScoresDialog *self) 
 {
-  if (self->_priv->hilight == 0) {
-    g_object_set (self->_priv->namerenderer, "editable", FALSE, NULL);
+  if (self->priv->hilight == 0) {
+    g_object_set (self->priv->namerenderer, "editable", FALSE, NULL);
     return;
   }
 
-  if (self->_priv->hilight == self->_priv->sethilight)
+  if (self->priv->hilight == self->priv->sethilight)
     return;
 
-  self->_priv->sethilight = self->_priv->hilight;
+  self->priv->sethilight = self->priv->hilight;
 
   /* We can't set the hilight editable immediately in case we are
    * still in the process of being created and the editing subwindow
@@ -257,34 +278,34 @@ static void games_scores_dialog_set_hilight_private (GamesScoresDialog *self)
 /* Load up the list with the current set of scores. */
 static void games_scores_dialog_redraw (GamesScoresDialog *self) {
   GtkTreeIter iter;
-  gchar *name;
+  const gchar *name;
   gint score;
   gchar *ss;
   gdouble dscore;
   GList *scorelist;
 
-  gtk_list_store_clear (self->_priv->list);
+  gtk_list_store_clear (self->priv->list);
 
-  scorelist = games_scores_get (self->_priv->scores);
+  scorelist = games_scores_get (self->priv->scores);
 
   while (scorelist) {
-    name = ((GamesScore *)scorelist->data)->name;
-    switch (self->_priv->style) {
+    name = games_score_get_name ((GamesScore *)scorelist->data);
+    switch (self->priv->style) {
     case GAMES_SCORES_STYLE_TIME_ASCENDING:
     case GAMES_SCORES_STYLE_TIME_DESCENDING:
-      dscore = ((GamesScore *)scorelist->data)->value.time_double;
-      score = rint (100*(dscore));
+      dscore = games_score_get_value_as_time ((GamesScore *)scorelist->data);
+      score = (int) (100.0 * dscore + 0.5);
       /* Translators: this is for a minutes, seconds time display. */
       ss = g_strdup_printf (_("%dm %ds"), score/100, score%100);
       break; 
     case GAMES_SCORES_STYLE_PLAIN_ASCENDING:
     case GAMES_SCORES_STYLE_PLAIN_DESCENDING:
     default:
-      score = ((GamesScore *)scorelist->data)->value.plain;
+      score = games_score_get_value_as_plain ((GamesScore *)scorelist->data);
       ss = g_strdup_printf ("%d", score);
     }
-    gtk_list_store_append (self->_priv->list, &iter);
-    gtk_list_store_set (self->_priv->list, &iter, 0, name, 1, ss, -1);
+    gtk_list_store_append (self->priv->list, &iter);
+    gtk_list_store_set (self->priv->list, &iter, 0, name, 1, ss, -1);
     g_free (ss);
     scorelist = g_list_next (scorelist);
   }
@@ -305,19 +326,19 @@ static void games_scores_dialog_change_category (GtkComboBox *widget,
   /* This seems like a bit of a hack, but since we're trying to
    * temporarily change the category it sort of makes sense. */
 
-  catcopy = g_strdup (games_scores_get_category (self->_priv->scores));
+  catcopy = g_strdup (games_scores_get_category (self->priv->scores));
   idx = gtk_combo_box_get_active (widget);
-  newcat = g_hash_table_lookup (self->_priv->catindices,
+  newcat = g_hash_table_lookup (self->priv->catindices,
 				 GINT_TO_POINTER (idx));
 
-  games_scores_set_category (self->_priv->scores, newcat);
-  if (self->_priv->preservehilight) {
-    self->_priv->preservehilight = FALSE;
+  games_scores_set_category (self->priv->scores, newcat);
+  if (self->priv->preservehilight) {
+    self->priv->preservehilight = FALSE;
   } else {
-    self->_priv->hilight = 0;
+    self->priv->hilight = 0;
   }
   games_scores_dialog_redraw (self);
-  games_scores_set_category (self->_priv->scores, catcopy);
+  games_scores_set_category (self->priv->scores, catcopy);
 
   g_free (catcopy);
 }
@@ -330,7 +351,7 @@ static void games_scores_dialog_show (GamesScoresDialog *self)
 { 
   const gchar *cat;
   
-  cat = games_scores_get_category (self->_priv->scores);
+  cat = games_scores_get_category (self->priv->scores);
   if (cat)
     games_scores_dialog_set_category (self, cat);
   games_scores_dialog_redraw (self);
@@ -338,8 +359,8 @@ static void games_scores_dialog_show (GamesScoresDialog *self)
 
 /* This is the other half of ensuring the hide/show cycle works properly. */
 static void games_scores_dialog_hide (GamesScoresDialog *self) {
-  self->_priv->hilight = 0;
-  gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (self->_priv->treeview));
+  self->priv->hilight = 0;
+  gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (self->priv->treeview));
 }
 
 /**
@@ -357,8 +378,8 @@ void games_scores_dialog_set_category_description (GamesScoresDialog *self,
   gchar *lstr;
 
   lstr = g_strdup_printf ("<b>%s</b>", description);
-  gtk_label_set_markup (GTK_LABEL (self->_priv->label), lstr);
-  gtk_label_set_use_underline (GTK_LABEL (self->_priv->label), TRUE);
+  gtk_label_set_markup (GTK_LABEL (self->priv->label), lstr);
+  gtk_label_set_use_underline (GTK_LABEL (self->priv->label), TRUE);
   g_free(lstr);
 }
 
@@ -374,12 +395,12 @@ void games_scores_dialog_set_message (GamesScoresDialog *self,
 				      const gchar *message)
 {
   if ((message == NULL) || (*message == '\0')) {
-    gtk_widget_hide (self->_priv->message);
-    gtk_widget_hide (self->_priv->hdiv);
+    gtk_widget_hide (self->priv->message);
+    gtk_widget_hide (self->priv->hdiv);
   } else {
-    gtk_widget_show (self->_priv->message);
-    gtk_widget_show (self->_priv->hdiv);
-    gtk_label_set_label (GTK_LABEL (self->_priv->message), message);
+    gtk_widget_show (self->priv->message);
+    gtk_widget_show (self->priv->hdiv);
+    gtk_label_set_label (GTK_LABEL (self->priv->message), message);
   }
 }
 
@@ -398,7 +419,7 @@ void games_scores_dialog_set_hilight (GamesScoresDialog *self, guint pos)
   if ((pos < 1) || (pos > GAMES_SCORES_SIGNIFICANT))
     return;
 
-  self->_priv->hilight = pos;
+  self->priv->hilight = pos;
   games_scores_dialog_set_hilight_private (self);
 }
 
@@ -458,23 +479,21 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
 
-  self->_priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GAMES_TYPE_SCORES_DIALOG,
-					     GamesScoresDialogPrivate);
+  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GAMES_TYPE_SCORES_DIALOG,
+                                            GamesScoresDialogPrivate);
 
-  self->_priv->style = GAMES_SCORES_STYLE_PLAIN_DESCENDING;
+  self->priv->style = GAMES_SCORES_STYLE_PLAIN_DESCENDING;
   /* These two hashes are the reverse of each other. As an optimisation 
    * they share the same set of strings (as keys in the first case and
    * as data in the second). The first hash is responsible for 
    * deallocating the memory for the strings. These two are only
    * valid as a pair. */
-  self->_priv->categories = g_hash_table_new_full (g_str_hash, g_str_equal,
+  self->priv->categories = g_hash_table_new_full (g_str_hash, g_str_equal,
 						     g_free, NULL);
-  self->_priv->catindices = g_hash_table_new (g_direct_hash, g_direct_equal);
-  self->_priv->catcounter = 0;
-  self->_priv->hilight = 0;
-  self->_priv->sethilight = -1;
-
-  gtk_dialog_set_has_separator (GTK_DIALOG (self), FALSE);
+  self->priv->catindices = g_hash_table_new (g_direct_hash, g_direct_equal);
+  self->priv->catcounter = 0;
+  self->priv->hilight = 0;
+  self->priv->sethilight = -1;
   gtk_container_set_border_width (GTK_CONTAINER (self), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), 2);
 
@@ -497,51 +516,51 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
 					 GTK_SHADOW_ETCHED_IN);
   gtk_box_pack_end (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
   
-  self->_priv->message = gtk_label_new ("");
-  gtk_label_set_use_markup (GTK_LABEL (self->_priv->message), TRUE);
-  gtk_label_set_justify (GTK_LABEL (self->_priv->message), 
+  self->priv->message = gtk_label_new ("");
+  gtk_label_set_use_markup (GTK_LABEL (self->priv->message), TRUE);
+  gtk_label_set_justify (GTK_LABEL (self->priv->message), 
 	                   GTK_JUSTIFY_CENTER);    
-  gtk_box_pack_start (GTK_BOX (vbox), self->_priv->message, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), self->priv->message, FALSE, FALSE, 0);
 
-  self->_priv->hdiv = gtk_hseparator_new ();
-  gtk_box_pack_start (GTK_BOX (vbox), self->_priv->hdiv, FALSE, FALSE, 0);
+  self->priv->hdiv = gtk_hseparator_new ();
+  gtk_box_pack_start (GTK_BOX (vbox), self->priv->hdiv, FALSE, FALSE, 0);
 
-  self->_priv->catbar = gtk_hbox_new (FALSE, 12);
-  gtk_box_pack_start (GTK_BOX (vbox), self->_priv->catbar, FALSE, FALSE, 0);
+  self->priv->catbar = gtk_hbox_new (FALSE, 12);
+  gtk_box_pack_start (GTK_BOX (vbox), self->priv->catbar, FALSE, FALSE, 0);
 
-  self->_priv->label = gtk_label_new (NULL);
-  gtk_label_set_use_markup (GTK_LABEL (self->_priv->label), TRUE);
-  gtk_box_pack_start (GTK_BOX (self->_priv->catbar), self->_priv->label,
+  self->priv->label = gtk_label_new (NULL);
+  gtk_label_set_use_markup (GTK_LABEL (self->priv->label), TRUE);
+  gtk_box_pack_start (GTK_BOX (self->priv->catbar), self->priv->label,
 			FALSE, FALSE, 0);	
  
-  self->_priv->combo = gtk_combo_box_new_text ();
-  gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (self->_priv->combo), FALSE);
-  gtk_box_pack_start (GTK_BOX (self->_priv->catbar), 
-			self->_priv->combo, TRUE, TRUE, 0);
-  gtk_label_set_mnemonic_widget (GTK_LABEL (self->_priv->label), self->_priv->combo);
+  self->priv->combo = gtk_combo_box_text_new ();
+  gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (self->priv->combo), FALSE);
+  gtk_box_pack_start (GTK_BOX (self->priv->catbar), 
+			self->priv->combo, TRUE, TRUE, 0);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (self->priv->label), self->priv->combo);
 
-  g_signal_connect (G_OBJECT (self->_priv->combo), "changed", 
+  g_signal_connect (G_OBJECT (self->priv->combo), "changed", 
 		      G_CALLBACK (games_scores_dialog_change_category), self);
 
-  self->_priv->list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+  self->priv->list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 
-  listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->_priv->list));
-  self->_priv->treeview = GTK_TREE_VIEW (listview);
-  self->_priv->cursor_handler_id = 
-    g_signal_connect (G_OBJECT (self->_priv->treeview), 
+  listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->priv->list));
+  self->priv->treeview = GTK_TREE_VIEW (listview);
+  self->priv->cursor_handler_id = 
+    g_signal_connect (G_OBJECT (self->priv->treeview), 
 			"cursor-changed", 
 			G_CALLBACK (games_scores_dialog_cursor_changed), self);
   
-  self->_priv->namerenderer = gtk_cell_renderer_text_new ();
-  g_signal_connect (self->_priv->namerenderer, "edited", 
+  self->priv->namerenderer = gtk_cell_renderer_text_new ();
+  g_signal_connect (self->priv->namerenderer, "edited", 
 		      G_CALLBACK (games_scores_dialog_name_edited), self);
 
-  self->_priv->namecolumn = gtk_tree_view_column_new_with_attributes (_("Name"),
-									self->_priv->namerenderer,
+  self->priv->namecolumn = gtk_tree_view_column_new_with_attributes (_("Name"),
+									self->priv->namerenderer,
 									"text", 0,
 									NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (listview),
-				 GTK_TREE_VIEW_COLUMN (self->_priv->namecolumn));
+				 GTK_TREE_VIEW_COLUMN (self->priv->namecolumn));
   renderer = gtk_cell_renderer_text_new ();
   /* Note that this assumes the default style is plain. */
   column = gtk_tree_view_column_new_with_attributes (_("Score"),
@@ -551,7 +570,7 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
   g_object_set (G_OBJECT (renderer), "xalign", 1.0, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (listview),
 				 GTK_TREE_VIEW_COLUMN (column));
-  self->_priv->column = column;
+  self->priv->column = column;
  
   gtk_container_add (GTK_CONTAINER (scroll), listview);
   
@@ -559,11 +578,11 @@ static void games_scores_dialog_init (GamesScoresDialog *self)
 
   gtk_window_set_destroy_with_parent (GTK_WINDOW (self), TRUE);
 
-  gtk_widget_grab_focus (self->_priv->combo);
+  gtk_widget_grab_focus (self->priv->combo);
 
   gtk_widget_show_all (vbox);
-  gtk_widget_hide (self->_priv->hdiv);
-  gtk_widget_hide (self->_priv->message);
+  gtk_widget_hide (self->priv->hdiv);
+  gtk_widget_hide (self->priv->message);
 }
 
 /* FIXME: There is basically no range checking. */
